# Generated by Django 2.2.4 on 2020-09-16 22:41

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('shortlink', '0002_auto_20200902_2012'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='shortlink',
            options={'verbose_name': 'Shortlink', 'verbose_name_plural': 'کوتاه\u200cکننده لینک'},
        ),
        migrations.AlterField(
            model_name='shortlink',
            name='full_url',
            field=models.CharField(max_length=500, verbose_name='آدرس URL اصلی برای کوتاه\u200cسازی'),
        ),
        migrations.AlterField(
            model_name='shortlink',
            name='name',
            field=models.CharField(blank=True, max_length=100, null=True, verbose_name='نام url'),
        ),
        migrations.AlterField(
            model_name='shortlink',
            name='short_path',
            field=models.CharField(db_index=True, max_length=100, verbose_name='مسیر کوتاه شده'),
        ),
    ]
