# Generated by Django 2.2.4 on 2020-09-16 22:42

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('shortlink', '0003_auto_20200916_2241'),
    ]

    operations = [
        migrations.AlterField(
            model_name='shortlink',
            name='short_path',
            field=models.CharField(blank=True, db_index=True, help_text='If not provided, will generate automatically', max_length=100, null=True, verbose_name='مسیر کوتاه شده'),
        ),
    ]
