# Generated by Django 2.2.5 on 2020-10-08 16:14

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('shortlink', '0005_auto_20200917_1707'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='shortlink',
            options={'verbose_name': 'Shortlink', 'verbose_name_plural': 'Shortlink'},
        ),
        migrations.AlterField(
            model_name='shortlink',
            name='full_url',
            field=models.CharField(max_length=500, verbose_name='Real URL to be shorten'),
        ),
        migrations.AlterField(
            model_name='shortlink',
            name='name',
            field=models.CharField(blank=True, max_length=100, null=True, verbose_name='Presentation name for url'),
        ),
        migrations.AlterField(
            model_name='shortlink',
            name='short_path',
            field=models.CharField(blank=True, db_index=True, help_text='If not provided, will generate automatically', max_length=100, null=True, verbose_name='Shorten Path ID'),
        ),
    ]
